# Notes2Py

## Установка

Мной были предусмотрены целых 3 способа установки приложения, они расположены в порядке возрастания сложности, все они подробно описаны в инструкции

### 1. Скачивание исполняемого файла (Windows, macOS)
Не требуется наличие Python и его библиотек в системе
* Заходим на страницу [последнего релиза](https://github.com/fast-geek/Notes2Py/releases/latest)
* Скачиваем файл для соответствующей операционной системы
* Открываем его и наслаждаемся

### 2. Установка с PyPi
Требуется наличие Python, библиотеки устанавливаются автоматически
* Устанавливаем Python с [официального сайта](https://www.python.org), если он не установлен 
* Открываем терминал и вводим команду установки, PIP установит необходимые библиотеки и саму программу (для Linux необходимо заменить `pip` на `pip3`)
```shell
pip install notes2py
```
* Запускаем программу
```shell
notes2py
```

### 3. Скачивание из репозитория
Требуется наличие Python, библиотеки устанавливаем отдельной командой
* Устанавливаем Python с [официального сайта](https://www.python.org), если он не установлен 
* Открываем терминал и клонируем репозиторий
```shell
git clone https://github.com/fast-geek/Notes2Py.git
```
* Переходим в папку программы и устанавливаем зависимости (для Linux необходимо заменить `pip` на `pip3`)
```shell
cd Notes2Py
pip install -r requirements.txt
```
* Можно также установить зависимости для разработки (Опционально)
```shell
pip install -r requirements-dev.txt
```
* Запускаем программу
```shell
python -m notes2py
```